@@ -4,7 +4,7 @@ package Emailesque;
 
 BEGIN {
     use Exporter();
-    use vars qw( @ISA @EXPORT @EXPORT_OK );
+    use vars qw(@ISA @EXPORT @EXPORT_OK);
     @ISA    = qw( Exporter );
     @EXPORT = qw(email);
 }
@@ -16,6 +16,8 @@ use Email::Sender::Transport::Sendmail;
 use Email::Sender::Transport::SMTP;
 use Email::Stuffer;
 
+our $VERSION = '1.200005'; # VERSION
+
 
 sub new {
     my $class = shift;
@@ -27,7 +29,7 @@ sub new {
 }
 
 sub email {
-    return Emailesque->new(@_)->send({});
+    return Emailesque->new(shift)->send(@_);
 }
 
 sub send {
@@ -194,7 +196,7 @@ Emailesque - Lightweight To-The-Point Email
 
 =head1 VERSION
 
-version 1.200004
+version 1.200005
 
 =head1 SYNOPSIS
 
